#
# spec file for package obs-service-cargo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obs-service-cargo
Summary:        OBS Source Service and utilities for Rust software packaging
License:        MPL-2.0
Group:          Development/Tools/Building
# Repository name subject to change
URL:            https://github.com/openSUSE/obs-service-cargo_vendor
Version:        0.8.4
Release:        1.1
Source0:        https://github.com/openSUSE/obs-service-cargo_vendor/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(libzstd)
Requires:       (cargo or rustup)
# At 0.6.0, vendor was introduced so we obsolete versions before that
Conflicts:      obs-service-cargo_vendor
Obsoletes:      obs-service-cargo_vendor
Provides:       obs-service-cargo_vendor = %{version}
# At 0.7.0, audit was introduced so we obsolete versions before that
Conflicts:      obs-service-cargo_audit
Obsoletes:      obs-service-cargo_audit
Provides:       obs-service-cargo_audit = %{version}

%description
This is an OBS Source Service that contains two main utilities:
- OBS Service Cargo Vendor
- OBS Service Cargo Audit

This vendors and audits dependencies for packaging Rust software.

%prep
# -n will be removed in the future if name changed
%autosetup -a1 -n %{name}_vendor-%{version}
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
install -m0755 %{_builddir}/%{name}_vendor-%{version}/target/release/cargo_vendor %{buildroot}%{_prefix}/lib/obs/service
install -m0755 %{_builddir}/%{name}_vendor-%{version}/target/release/cargo_audit  %{buildroot}%{_prefix}/lib/obs/service
install -m0644 cargo_vendor.service %{buildroot}%{_prefix}/lib/obs/service
install -m0644 cargo_audit.service %{buildroot}%{_prefix}/lib/obs/service

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service

%changelog
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.4:
  * fix: also check attempt to vendor if it is also a workspace
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.3:
  * misc: add stop sign in error message
  * improve error handling impl
  * fix: also make sure it really has no deps
  * utils: exit vendor step if no dependencies found
  * update README again
  * update README
  * docs: update README regarding the new flag
  * all: apply clippy lint suggestions
  * fix: also copy top-level folder if src is a directory
  * Rework of compression and vendoring to be clearer
  * Minor output improvements
  * fix: also copy top-level folder if src is a directory
  * update email address in manifest file
  * remove unused dead code
  * clippy: apply clippy suggestions
* Thu Oct 12 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.8.0:
  * audit is no-op and it is now part of vendor process.
  * cargo_audit binary will execute nothing now.
* Wed Oct 11 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.5:
  * globbed tar now supports lexicographical order
  * improved rustsec output
* Mon Oct  9 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.4:
  * fix: decompressed tarball may or may not have a top-level folder
* Sat Oct  7 2023 William Brown <william.brown@suse.com>
- Change obsoletes to not list a version as we obsolete all versions.
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.3.
  * small fixes and changes
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.7.1. No changes.
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.7.0:
  * refactor cargo vendor
  * feature audit
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Change to 0.6.0 release
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for obs-service-cargo. 0.6.0-alpha
